#!/bin/bash
# Usage: LaunchIris.sh [iris configuration file]
#
# Set JAVA_EXE to specify the java instance to use
# export JAVA_EXE=/my/java; LaunchIris.sh
# JAVA_EXE=/my/java LaunchIris.sh

DEVROOT=`dirname $0`

# find out if JAVA_EXE is set to a non-empty value
if [ -z $JAVA_EXE ]; then
    # not set - try to guess
    if [ ! -z $JAVA_HOME ]; then
        [ -x "$JAVA_HOME/bin/java" ] && JAVA_EXE=$JAVA_HOME/bin/java
    fi
fi

# if it's still not set, just use "java"
[ -z $JAVA_EXE ] && JAVA_EXE=java

$JAVA_EXE -d64 -version > /dev/null 2>&1

if [ $? != 0 ]; then
    echo "Default java $JAVA_EXE is not 64 bit, trying to find 64 bit version..."
    unset JAVA_EXE
    for x in `ls -1t /usr/java/*/bin/java`; do
        xout=$($x -d64 -version 2>&1)
        if [ $? == 0 ]; then
            if [[ "$xout" =~ "build 1.8" ]]; then
                JAVA_EXE=$x
                echo "Found 64bit java 1.8 at $JAVA_EXE, using it."
                break
            fi
        fi
    done

    if [ -z $JAVA_EXE ]; then
        echo "Error, could not locate 64bit java 1.8. Please set JAVA_HOME to the location of a 64bit JDK 1.8 install."
        exit 1
    fi
fi

(cd $DEVROOT; $JAVA_EXE -cp "*" com.illumon.iris.bootstrap.IrisConfigurationLauncher $*)